==> afya_moja_core-0.0.99.tar.gz: lib/src/app_asset_strings.dart <==
// Search
const String magnifierToolIconSvg = 'assets/icons/magnifier_tool.svg';

//User Profile
const String editProfileIconSvg = 'assets/icons/edit_profile_icon.svg';
const String phoneCallIcon = 'assets/icons/phone_call_icon.svg';
const String homeLocationIcon = 'assets/icons/home_location_icon.svg';

// Community Chat
const String awaitingModerationIcon =
    'assets/icons/awaiting_moderation_icon.svg';
const String attachFileIcon = 'assets/icons/attach_file.svg';
const String sendTextIcon = 'assets/icons/send_text.svg';

const String errorPageImageSvgPath =
    'packages/afya_moja_core/assets/error_page_image.svg';
const String tooManyAttemptsIconSvgPath =
    'packages/afya_moja_core/assets/too_many_attempts_icon.svg';

//content
const String saveIconUrl = 'packages/afya_moja_core/assets/save.svg';
const String shareIconUrl = 'packages/afya_moja_core/assets/share.svg';
const String heartIconUrl = 'packages/afya_moja_core/assets/heart.svg';
const String placeholderImageUrl = 'packages/afya_moja_core/assets/placeholder_image.svg';
const String contentImagePlaceHolderSvgPath =
    'packages/afya_moja_core/assets/content_image_placeholder.png';
const String contentIconSvgPath = 'packages/afya_moja_core/assets/content_icon.svg';
const String playIcon = 'packages/afya_moja_core/assets/playIcon.svg'; //pdf icon
const String pdfIconSvg = 'packages/afya_moja_core/assets/pdf_icon.svg';
const String profileImage = 'packages/afya_moja_core/assets/profile_image.png';
const String whiteCloseIconSvgPath = 'packages/afya_moja_core/assets/white_close_icon.svg';
const String emptyStateCover = 'packages/afya_moja_core/assets/no_content_image.svg';

==> afya_moja_core-0.2.0.tar.gz: lib/src/app_asset_strings.dart <==
// Search
const String magnifierToolIconSvg = 'assets/icons/magnifier_tool.svg';

//User Profile
const String editProfileIconSvg = 'assets/icons/edit_profile_icon.svg';
const String phoneCallIcon = 'assets/icons/phone_call_icon.svg';
const String homeLocationIcon = 'assets/icons/home_location_icon.svg';

// Community Chat
const String awaitingModerationIcon =
    'assets/icons/awaiting_moderation_icon.svg';
const String attachFileIcon = 'assets/icons/attach_file.svg';
const String sendTextIcon = 'assets/icons/send_text.svg';

const String errorPageImageSvgPath =
    'packages/afya_moja_core/assets/error_page_image.svg';
const String tooManyAttemptsIconSvgPath =
    'packages/afya_moja_core/assets/too_many_attempts_icon.svg';

//content
const String saveIconUrl = 'packages/afya_moja_core/assets/save.svg';
const String shareIconUrl = 'packages/afya_moja_core/assets/share.svg';
const String heartIconUrl = 'packages/afya_moja_core/assets/heart.svg';
const String placeholderImageUrl =
    'packages/afya_moja_core/assets/placeholder_image.svg';
const String contentImagePlaceHolderSvgPath =
    'packages/afya_moja_core/assets/content_image_placeholder.png';
const String contentIconSvgPath =
    'packages/afya_moja_core/assets/content_icon.svg';
const String playIcon =
    'packages/afya_moja_core/assets/playIcon.svg'; //pdf icon
const String pdfIconSvg = 'packages/afya_moja_core/assets/pdf_icon.svg';
const String whiteCloseIconSvgPath =
    'packages/afya_moja_core/assets/white_close_icon.svg';
const String emptyStateCover =
    'packages/afya_moja_core/assets/no_content_image.svg';
